@@ -63,7 +63,7 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GeditMultiNotebook, gedit_multi_notebook, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (GeditMultiNotebook, gedit_multi_notebook, GTK_TYPE_BOX)
 
 static void	remove_notebook		(GeditMultiNotebook *mnb,
 					 GtkWidget          *notebook);
@@ -461,7 +461,6 @@ add_notebook (GeditMultiNotebook *mnb,
 		gboolean collapse_new_notebook = FALSE;
 
 		paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
-		gtk_widget_set_vexpand (paned, TRUE);
 		gtk_widget_show (paned);
 
 		/* First we remove the active container from its parent to make
@@ -591,6 +590,9 @@ gedit_multi_notebook_init (GeditMultiNotebook *mnb)
 
 	mnb->priv->removing_notebook = FALSE;
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (mnb),
+	                                GTK_ORIENTATION_VERTICAL);
+
 	mnb->priv->active_notebook = gedit_notebook_new ();
 	add_notebook (mnb, mnb->priv->active_notebook, TRUE);
 }
@@ -791,12 +793,12 @@ gedit_multi_notebook_close_tabs (GeditMultiNotebook *mnb,
 			gint n;
 
 			n = gtk_notebook_page_num (GTK_NOTEBOOK (nbs->data),
-						   GTK_WIDGET (l->data));
+			                           GTK_WIDGET (l->data));
 
 			if (n != -1)
 			{
-				gedit_notebook_remove_tab (GEDIT_NOTEBOOK (nbs->data),
-				                           GEDIT_TAB (l->data));
+				gtk_container_remove (GTK_CONTAINER (nbs->data),
+				                      GTK_WIDGET (l->data));
 				break;
 			}
 		}
