@@ -454,7 +454,7 @@ build_suggestion_menu (GeditAutomaticSpellChecker *spell, const gchar *word)
 			
 			label = gtk_label_new (label_text);
 			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-			gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+			gtk_widget_set_halign (label, GTK_ALIGN_START);
 
 			mi = gtk_menu_item_new ();
 			gtk_container_add (GTK_CONTAINER(mi), label);
